@@ -379,23 +379,38 @@ optional `tmr--timer-description'."
   "Return a string representing when TIMER should finish."
   (tmr--format-time (tmr--timer-end-date timer)))
 
+(defun tmr--format-seconds (seconds)
+  "Format the SECONDS in a human-readable way."
+  (cond
+   ((>= seconds 3600) (format "%sh %sm" (/ seconds 3600) (/ (% seconds 3600) 60)))
+   ((>= seconds 60) (format "%sm %ss" (/ seconds 60) (% seconds 60)))
+   (t (format "%ss" seconds))))
+
+(defun tmr--get-seconds (timer)
+  "Get the TIMER in seconds."
+  (round (- (float-time (tmr--timer-end-date timer)) (float-time))))
+
 (defun tmr--format-remaining (timer)
   "Format remaining time of TIMER."
   (if (tmr--timer-finishedp timer)
       tmr-finished-indicator
-    (let* ((secs (round (- (float-time (tmr--timer-end-date timer))
-                           (float-time))))
-           (str (if (> secs 3600)
-                    (format "%sh %sm" (/ secs 3600) (/ (% secs 3600) 60))
-                  (if (> secs 60)
-                      (format "%sm %ss" (/ secs 60) (% secs 60))
-                    (format "%ss" secs)))))
-      (if (< secs 0)
+    (let* ((seconds (tmr--get-seconds timer))
+           (str (tmr--format-seconds seconds)))
+      (if (< seconds 0)
           ;; Negative remaining time occurs for non-acknowledged timers with
           ;; additional duration.
           (propertize str 'face 'tmr-must-be-acknowledged)
         str))))
 
+(defun tmr--format-duration (timer)
+  "Format duration of TIMER."
+  (let ((input (tmr--timer-input timer)))
+    (if (string-match-p ":" input)
+        (tmr--format-seconds (tmr--get-seconds timer))
+      (if (string-match-p "\\`[0-9]+\\(?:\\.[0-9]+\\)?\\'" input)
+          (concat input "m")
+        input))))
+
 (defun tmr--format-time (time)
   "Return a human-readable string representing TIME."
   (format-time-string "%T" time))
@@ -527,22 +542,45 @@ If there are no timers, throw an error."
             (user-error "No timer selected")))))))
 
 (declare-function notifications-notify "notifications" (&rest params))
+(declare-function android-notifications-notify "androidselect.c" (&rest params))
+(declare-function w32-notification-notify "w32fns.c" (&rest params))
+(declare-function haiku-notifications-notify "haikuselect.c" (&rest params))
 
 (defun tmr-notification-notify (timer)
   "Dispatch a notification for TIMER.
 Read Info node `(elisp) Desktop Notifications' for details."
-  (if (featurep 'dbusbind)
+  (if (or (featurep 'dbusbind)
+          (seq-some #'fboundp
+                    (list #'android-notifications-notify
+                          #'w32-notification-notify
+                          #'haiku-notifications-notify)))
       (let ((title "TMR May Ring (Emacs tmr package)")
             (body (tmr--long-description-for-finished-timer timer)))
-        (unless (fboundp 'notifications-notify)
-          (require 'notifications))
-        (notifications-notify
-         :title title
-         :body body
-         :app-name "GNU Emacs"
-         :app-icon 'emacs
-         :urgency tmr-notification-urgency
-         :sound-file tmr-sound-file))
+        (cond ((fboundp 'android-notifications-notify)
+               (android-notifications-notify
+                :title title
+                :body body
+                :urgency tmr-notification-urgency))
+              ((fboundp 'w32-notification-notify)
+               (w32-notification-notify
+                :title title
+                :body body))
+              ((fboundp 'haiku-notifications-notify)
+               (haiku-notifications-notify
+                :title title
+                :body body
+                :app-icon 'emacs
+                :urgency tmr-notification-urgency))
+              (t
+               (unless (fboundp 'notifications-notify)
+                 (require 'notifications))
+               (notifications-notify
+                :title title
+                :body body
+                :app-name "GNU Emacs"
+                :app-icon 'emacs
+                :urgency tmr-notification-urgency
+                :sound-file tmr-sound-file))))
     (display-warning 'tmr "Emacs has no DBUS support, TMR notifications unavailable")))
 
 ;; NOTE 2022-04-21: Emacs has a `play-sound' function but it only
@@ -825,6 +863,7 @@ they are set to reasonable default values."
    (vector
     (propertize (tmr--format-creation-date timer) 'face 'tmr-tabulated-start-time)
     (propertize (tmr--format-end-date timer) 'face 'tmr-tabulated-end-time)
+    (propertize (tmr--format-duration timer) 'face 'tmr-duration)
     (propertize (tmr--format-remaining timer) 'face 'tmr-tabulated-remaining-time)
     (propertize (if (tmr--timer-acknowledgep timer) "Yes" "") 'face 'tmr-tabulated-acknowledgement)
     (propertize (or (tmr--timer-description timer) "") 'face 'tmr-tabulated-description))))
@@ -847,7 +886,7 @@ they are set to reasonable default values."
                               (let ((end (eobp)))
                                 ;; Optimized refreshing
                                 (dolist (entry tabulated-list-entries)
-                                  (setf (aref (cadr entry) 2)
+                                  (setf (aref (cadr entry) 3)
                                         (propertize (tmr--format-remaining (car entry)) 'face 'tmr-tabulated-remaining-time)))
                                 (tabulated-list-print t)
                                 (when end (goto-char (point-max))))
@@ -877,6 +916,7 @@ they are set to reasonable default values."
   (setq-local tabulated-list-format
               [("Start" 10 t)
                ("End" 10 t)
+               ("Duration" 10 t)
                ("Remaining" 10 tmr-tabulated--compare-remaining)
                ("Acknowledge?" 14 t)
                ("Description" 0 t)])
